==> liboobs-2.21.2.1.tar.bz2: liboobs-2.21.2.1/oobs/oobs.h <==
/* -*- Mode: C; c-file-style: "gnu"; tab-width: 8 -*- */
/* Copyright (C) 2005 Carlos Garnacho
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
 */

#ifndef __OOBS_H_
#define __OOBS_H_

#include <glib-object.h>
#include <oobs/oobs-object.h>
#include <oobs/oobs-session.h>
#include <oobs/oobs-list.h>
#include <oobs/oobs-selfconfig.h>
#include <oobs/oobs-share.h>
#include <oobs/oobs-share-smb.h>
#include <oobs/oobs-smbconfig.h>
#include <oobs/oobs-share-nfs.h>
#include <oobs/oobs-nfsconfig.h>
#include <oobs/oobs-user.h>
#include <oobs/oobs-usersconfig.h>
#include <oobs/oobs-group.h>
#include <oobs/oobs-groupsconfig.h>
#include <oobs/oobs-ntpserver.h>
#include <oobs/oobs-ntpconfig.h>
#include <oobs/oobs-timeconfig.h>
#include <oobs/oobs-statichost.h>
#include <oobs/oobs-hostsconfig.h>
#include <oobs/oobs-iface.h>
#include <oobs/oobs-iface-ethernet.h>
#include <oobs/oobs-iface-wireless.h>
#include <oobs/oobs-iface-irlan.h>
#include <oobs/oobs-iface-plip.h>
#include <oobs/oobs-iface-isdn.h>
#include <oobs/oobs-iface-modem.h>
#include <oobs/oobs-ifacesconfig.h>
#include <oobs/oobs-service.h>
#include <oobs/oobs-servicesconfig.h>
#include <oobs/oobs-result.h>

#endif /* __OOBS_H_ */

==> liboobs-2.29.2.1.tar.bz2: liboobs-2.29.2.1/oobs/oobs.h <==
/* -*- Mode: C; c-file-style: "gnu"; tab-width: 8 -*- */
/* Copyright (C) 2005 Carlos Garnacho
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Carlos Garnacho Parro  <carlosg@gnome.org>
 */

#ifndef __OOBS_H_
#define __OOBS_H_

#include <glib-object.h>
#include <oobs/oobs-object.h>
#include <oobs/oobs-enum-types.h>
#include <oobs/oobs-session.h>
#include <oobs/oobs-list.h>
#include <oobs/oobs-defines.h>
#include <oobs/oobs-selfconfig.h>
#include <oobs/oobs-share.h>
#include <oobs/oobs-share-smb.h>
#include <oobs/oobs-smbconfig.h>
#include <oobs/oobs-share-nfs.h>
#include <oobs/oobs-nfsconfig.h>
#include <oobs/oobs-user.h>
#include <oobs/oobs-usersconfig.h>
#include <oobs/oobs-group.h>
#include <oobs/oobs-groupsconfig.h>
#include <oobs/oobs-ntpserver.h>
#include <oobs/oobs-ntpconfig.h>
#include <oobs/oobs-timeconfig.h>
#include <oobs/oobs-statichost.h>
#include <oobs/oobs-hostsconfig.h>
#include <oobs/oobs-iface.h>
#include <oobs/oobs-iface-ethernet.h>
#include <oobs/oobs-iface-wireless.h>
#include <oobs/oobs-iface-irlan.h>
#include <oobs/oobs-iface-plip.h>
#include <oobs/oobs-iface-ppp.h>
#include <oobs/oobs-ifacesconfig.h>
#include <oobs/oobs-service.h>
#include <oobs/oobs-servicesconfig.h>
#include <oobs/oobs-result.h>

#endif /* __OOBS_H_ */
